;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x032774fe18a6eeb07b70d7721cd788bd . "./code.cg2js/cg-acache.fasl")
(#x81cd3daec4fcbc32244312cbb62b67a6 . "./code.cg2js/cg-base.fasl")
(#x0e21ab661201934079b5a9f4130625ad . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x839879e2a27f4d1ab013c5c38a9f6e6a . "./code.cg2js/cg-bitmap-pane.fasl")
(#x1214f5b0c58b2340eadc7f0f196b2632 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x73ccb2e360c3e784d041ed54c27ed9c1 . "./code.cg2js/cg-button.fasl")
(#x7ab4405183d9024b02a305ef7890ac70 . "./code.cg2js/cg-calendar.fasl")
(#xaed6ebbe27d7b2eaa18c29291f57b699 . "./code.cg2js/cg-caret.fasl")
(#x4bf9d763ac8e028c7697ea59f8a76e05 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x1bd7542aaf8ace5550589234171b255f . "./code.cg2js/cg-chart-widget.fasl")
(#xf53ca1c80b6586148c673be7ce4757d9 . "./code.cg2js/cg-check-box.fasl")
(#x1957c69674b0125e4b83a5bc23f7b9ce . "./code.cg2js/cg-choice-list.fasl")
(#xf05216bff6c3951e54d4ce820b485ece . "./code.cg2js/cg-choose-printer.fasl")
(#x42ea9c05e46b2044f80f661e90558d0f . "./code.cg2js/cg-class-grid.fasl")
(#xbe1d9f77745e426af266dae9c58fc045 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x28aec7b60e22853c0f7e2476ca447e46 . "./code.cg2js/cg-class-support.fasl")
(#x9fcf0af2e62d6a871ce301e4a12e3a4d . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xd2585199bd60eeadddf0acd42a290331 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x55bcbbec47a5a1cffdbdf624049a6c8e . "./code.cg2js/cg-clipboard.fasl")
(#x0326cb3c70d716b56caddefe1a08053e . "./code.cg2js/cg-color-dialog.fasl")
(#x1bf93fb6a14d0a5cf128805db6178ec3 . "./code.cg2js/cg-combo-box.fasl")
(#x803ec29e4da311abc0e5a3ff2b9f9380 . "./code.cg2js/cg-common-control.fasl")
(#xc909a4cffaaa29c7e966c4a684107175 . "./code.cg2js/cg-comtab.fasl")
(#x2638a6bd560a94bcf83d23378f091efe . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xbf579c3b6ff985a4662d7aa435e520ee . "./code.cg2js/cg-curve.fasl")
(#x4a9517187d5482b2f80aa40f9509dbff . "./code.cg2js/cg-dde-utils.fasl")
(#xa9e24aff7c7eff96ea7cf7068f951fad . "./code.cg2js/cg-dev.fasl")
(#x09e4c643e5be89cd16b4e6bbecd95b16 . "./code.cg2js/cg-dialog-item.fasl")
(#x585b7e6b5568616f070472691ea2a840 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xcb12bc64ea446c515606ee9c3cfbce54 . "./code.cg2js/cg-directory-dialog.fasl")
(#x2a2de306a09479a93221ea48af0ea44c . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xef72abc81494654c04699cce4e9f241b . "./code.cg2js/cg-drag-and-drop.fasl")
(#x4e19731c8818bc3636e156bfc0b75d57 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xa5c07474637ce05593f35fe91758e23d . "./code.cg2js/cg-drawable.fasl")
(#x7fafa12d8bbe0fc9cabd2bfd0d3356ea . "./code.cg2js/cg-dropping-outline.fasl")
(#x71b863f4d1697e128cb8f50ec0a8333f . "./code.cg2js/cg-edit-in-place.fasl")
(#xb7fd9dc6d4ea903f52e0b3cc9bb5b2d6 . "./code.cg2js/cg-editable-text.fasl")
(#xf5b4b151972c98873bfff925bb7b9bfb . "./code.cg2js/cg-file-dialog.fasl")
(#x6297af9c177c5df9b0af30b4bdc3b513 . "./code.cg2js/cg-fill-texture.fasl")
(#xf4ea13844ce4232d0544978287a6e905 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x8fa420872d091cb5d024192bd83deae4 . "./code.cg2js/cg-font-dialog.fasl")
(#x36b2eecbeb219dd619eb1c4868a9b408 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xcdd058f0bf4df8911d3e6f9075fe89e6 . "./code.cg2js/cg-get-pixmap.fasl")
(#x26809c2f43997ccf84cf108d849b50f3 . "./code.cg2js/cg-get-position.fasl")
(#xfc04404ea9c20c5a586b684d47cc5aa9 . "./code.cg2js/cg-graphics-context.fasl")
(#xfbb48192bb3e27468e58b121e4a81381 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x39a52ecb1045153ce02126e3bd5b1b1b . "./code.cg2js/cg-grid-widget.fasl")
(#xcf50735958f683865944acd37788c7f7 . "./code.cg2js/cg-group-box.fasl")
(#x719831cbf7cb1b4e8732e93b7e506565 . "./code.cg2js/cg-header-control.fasl")
(#xe26dbf6a908b4aecf1b1c8ba6caefca6 . "./code.cg2js/cg-hotspot.fasl")
(#xa83556478a763a707953f6c11e442c40 . "./code.cg2js/cg-html-dialog.fasl")
(#xd1570e3588f20844b8f789af6aff8173 . "./code.cg2js/cg-html-widget.fasl")
(#x159a37123dfbf14625c370eef9962a0a . "./code.cg2js/cg-icon-pixmap.fasl")
(#x447edccab2b7ee1e073e571735a480d7 . "./code.cg2js/cg-icon.fasl")
(#x08231ed05b8a6566ea95dd9379fd1c73 . "./code.cg2js/cg-ie.fasl")
(#x490bc2d149c387ed62e258604b35d34a . "./code.cg2js/cg-intersect-posbox.fasl")
(#x215152f62dc51039d1084ad1ed60b491 . "./code.cg2js/cg-intersect.fasl")
(#x16a8b3d8d5824fbb225b03f5d3906e07 . "./code.cg2js/cg-item-list.fasl")
(#xb455114f75043f5f2bcabb989054bb5d . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x90440ec3cca287f26cf658c867035145 . "./code.cg2js/cg-lamp.fasl")
(#x7ebac68952b9875d338c1d8f4755cc65 . "./code.cg2js/cg-layout.fasl")
(#x133474266120823f6f0c28c3f8aadf57 . "./code.cg2js/cg-lettered-menu.fasl")
(#x9e07e8afd7c51f9da4eb9123825c2248 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x2ea65cd224fac89e921943de558433d9 . "./code.cg2js/cg-lisp-text.fasl")
(#x25f7510fa88a88763956adf09114c350 . "./code.cg2js/cg-lisp-widget.fasl")
(#x58b137037ff6918b66d956ec9eeef8ed . "./code.cg2js/cg-list-view.fasl")
(#xdca5d1f020e2d6e7699e8c8908473ec7 . "./code.cg2js/cg-mci.fasl")
(#xf096e67c367ce0e259ec62d04a6a2c6e . "./code.cg2js/cg-menu-tooltip.fasl")
(#xfa3499407fdc0ff814c11245592063b3 . "./code.cg2js/cg-menu.fasl")
(#x3b79c4486f7f9876dec739f2b8c5594a . "./code.cg2js/cg-message-dialog.fasl")
(#x346bcaee958e9db1acfbb8063f86445b . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x7b203cfa94e8e1393ad8c4473159a5b5 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x792a9c3eb9a2632d800d79e4b7c830d3 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x2d9811b6cbcad6c64091e69f53eafd56 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x43c1a8b086e1c81f5996110a127e3c5b . "./code.cg2js/cg-multi-picture-button.fasl")
(#x2593ce9be6e652a27fcccbf609a55f14 . "./code.cg2js/cg-nodes.fasl")
(#xea76f91cfe49bbefabc40ac03553dbea . "./code.cg2js/cg-object-editor-layout.fasl")
(#x24cdf7ec0ab35f1be3411f08ea13b706 . "./code.cg2js/cg-object-editor.fasl")
(#x3b122176da77995fd5c85f7845afacdb . "./code.cg2js/cg-ocx.fasl")
(#x68907d2db52bd67bdcde267f9d46ec1e . "./code.cg2js/cg-os-widget.fasl")
(#xd2cc244fc3124a11709e66334f7e94d8 . "./code.cg2js/cg-os-window.fasl")
(#xf21b21900902a251a0e4b6d64f152f2c . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x7a9b2e0868770aa421efa0e5c54e5757 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x55ef3c096c480a643df8e7e50d31d972 . "./code.cg2js/cg-outline.fasl")
(#x8295b961c1ca9f9da5f4f06ede6bad7a . "./code.cg2js/cg-palette.fasl")
(#x5d201f076550eb9b36b8063c9f503a4c . "./code.cg2js/cg-paren-matching.fasl")
(#xbb709b6e255ca5a684b937c3775d9a13 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x19705bfeae92d861845c6af8bb2ce6c3 . "./code.cg2js/cg-picture-widget.fasl")
(#x6ad4c9a6cf60b0db2e043f3cda124d64 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xe0b714a5497f1227fa19af77539a32db . "./code.cg2js/cg-pixmap-printing.fasl")
(#x7fcf3ad33413501e5bbb4e789604c341 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x7f09397e8cec36b47c06eb9dcfec116a . "./code.cg2js/cg-pixmap-widget.fasl")
(#xb1ea87e4a4966834f3f3ef839e30d338 . "./code.cg2js/cg-pixmap.fasl")
(#x13b92349797f26329a2ddfa809282798 . "./code.cg2js/cg-player.fasl")
(#x86476f217cc58290ae76d59480917de0 . "./code.cg2js/cg-plot-widget.fasl")
(#x2b2e5e39c0dc12f6d30acd0950bf7f60 . "./code.cg2js/cg-printing.fasl")
(#xddb903e4cacafee5dcbcaa7d50e727cc . "./code.cg2js/cg-progress-indicator.fasl")
(#xbd86cdcb0eed53f1c49004bc610a3c94 . "./code.cg2js/cg-project-window.fasl")
(#x840906b4e11218c17d4e5c63d32f7fa7 . "./code.cg2js/cg-property.fasl")
(#x0825e3bdf987d0c6ec3f9bd36f211e2e . "./code.cg2js/cg-radio-button.fasl")
(#x8643dc2e087ecd8a4ea99edcef3e2c2e . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xdfec3039c5cf32b37c351086f56c0593 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x285bb003e093342d2135500f271a501b . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x42267be661f17e3328bb54f177819de5 . "./code.cg2js/cg-rich-edit.fasl")
(#x67c8e9b6c4487080261a2b674a0f994b . "./code.cg2js/cg-sample-file-menu.fasl")
(#xf565ec693c8c4cb826eabdf0610c1576 . "./code.cg2js/cg-scaling-stream.fasl")
(#x1641eff30533aef3895d1943010fdb57 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x3119266d189eea666b7d3e064ba2bd3e . "./code.cg2js/cg-scroll-bar.fasl")
(#x68a7c478ac548d1b42536866ffb61e3a . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xc9752b7834a88e5d7a572ab9ef6e0d49 . "./code.cg2js/cg-selected-object.fasl")
(#xfc72c3f671bdd6d06bb878885d89ba33 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x01fa5e0ead8bdb93a73bc5b27e49a411 . "./code.cg2js/cg-split-bar.fasl")
(#x9b213228ec680522e95b7144425974c1 . "./code.cg2js/cg-static-text.fasl")
(#xcd73a173392f3467cb469296664e0b70 . "./code.cg2js/cg-status-bar.fasl")
(#xa8a435043eef838180b51f7952bb2879 . "./code.cg2js/cg-string-dialog.fasl")
(#x5a21c4613702d7294784077685a5ce67 . "./code.cg2js/cg-tab-control.fasl")
(#xcf8f917d06a46169942309173b8f0856 . "./code.cg2js/cg-template-string.fasl")
(#x792809aa540fa13ba6b6f10e43ef2f03 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xdbed0b865437f0b4af613e8621da9593 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xe667d9035c9b1e1a1db5a8cef97dde87 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x9f72536598e194e8bad58a7e80c981f0 . "./code.cg2js/cg-text-or-combo.fasl")
(#x2849fcbe9ee3f6669983a9ca885b50c7 . "./code.cg2js/cg-text-widget.fasl")
(#x2e368291d1a1093b607f204543cd8aca . "./code.cg2js/cg-timer.fasl")
(#xd58637b5352ad89edc0a5f5cf2862dd6 . "./code.cg2js/cg-toggling-widget.fasl")
(#x9b043178ca501c197773b4ee913b6038 . "./code.cg2js/cg-toolbar.fasl")
(#x3b85e99b391dd041765ccaa2ea9b4326 . "./code.cg2js/cg-tooltip.fasl")
(#x8a6ab51389df2927517512e6d42e747c . "./code.cg2js/cg-touch.fasl")
(#x28fd52e408d7c22f1ca89e4660803a8a . "./code.cg2js/cg-trackbar.fasl")
(#x31fa5acb93d0874c7e623f3d5e2646ad . "./code.cg2js/cg-tray.fasl")
(#x6372c624237c4d5e2bdd2cbe4deb6f25 . "./code.cg2js/cg-up-down-control.fasl")
(#x7eebf3157fea286ebd54498de940fb22 . "./code.cg2js/cg-utility-dialog.fasl")
(#xe2624ec6e888ca48eccca8ba8b58eac0 . "./code.cg2js/cg-web-browser-dde.fasl")
(#x225471f9c5fbdabf4b4d6f9cc9d1cc09 . "./code.cg2js/cg-web-browser.fasl")
(#x22e8dc07d72c581e0ed1f663c6ae0c65 . "./code.cg2js/cg-wrap-string.fasl")
(#x1e57f9eb09ff507f9e8420838215ffcd . "./code.cg2js/cg-yes-no-list.fasl")
(#x343055674cd744646cc10307e375118c . "./code.cg2js/cg.fasl")
(#x8712e5e7ea93b6596606a5f0448488c4 . "./code.cg2js/cg-yes-no-string.fasl")
(#xf17f7285f67a4271942c966a6e6507e0 . "./code.idejs/ide-acache.fasl")
(#x6720fa58ca0ec229fae8e7dd6b308ec3 . "./code.idejs/ide-apropos.fasl")
(#x590edc0e5f6a948d4fd1bdbddd3abad8 . "./code.idejs/ide-base.fasl")
(#x4598ea2cda832253753b6bb2a2fe369d . "./code.idejs/ide-class-browser.fasl")
(#x87fbf8c06ca4ae9c9577e8a033842d0b . "./code.idejs/ide-class-grapher.fasl")
(#x9d97539ca76ed8a8b292de74b75c3245 . "./code.idejs/ide-clipboard.fasl")
(#x5f177be8edbfeba3245e723e9e580ffc . "./code.idejs/ide-dev.fasl")
(#x9ad8627f4570cc693a1cf40b75f89d56 . "./code.idejs/ide-editor.fasl")
(#xadd27edeac0637300652e2248806457d . "./code.idejs/ide-find-definitions.fasl")
(#x25eb82b537285f43d45985fb4c47a4e8 . "./code.idejs/ide-find-in-files.fasl")
(#xf8e37cff57cfe855b46bd5fd697e1a98 . "./code.idejs/ide-form.fasl")
(#x23f9b95b89ad49094c08a0eba712ed87 . "./code.idejs/ide-grapher.fasl")
(#x42fd2e928b59788c589969a6973e178d . "./code.idejs/ide-inspector.fasl")
(#x41ec26f3065192131f71e78097991426 . "./code.idejs/ide-intro.fasl")
(#xbce51efb79e27d0b59a39b21baf35965 . "./code.idejs/ide-keyshort.fasl")
(#xa86840d92e16233ddd474b2a1fcb363e . "./code.idejs/ide-navigator.fasl")
(#x3f4e140b5a5e76a204e4adf768e7a737 . "./code.idejs/ide-package-list.fasl")
(#x3f53f93bc092bd412a0824ac5a0f16fa . "./code.idejs/ide-patch-dialog.fasl")
(#xa38859b55192d6bb9a0292bf1103ce2e . "./code.idejs/ide-process-browser.fasl")
(#xa2a28bf84ae68338101eef29d429a678 . "./code.idejs/ide-project.fasl")
(#xcaae43665ad4029dc1500464ab7dc8af . "./code.idejs/ide-trace.fasl")
(#x7808cd1072ccf5f91ef6973fb73b6a30 . "./code.idejs/ide-window-list.fasl")
(#x967124cd93e492b49e0ba93348b136c5 . "./code.idejs/ide.fasl")
(#xde049c9404b4ba293f0cbc6a4817dc96 . "./cgjs.html")
(#x55fea08d92e113f5a8381c271febbc9e . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (format t "Incorrect checksum on file: ~a" (cdr checksum))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows
  (let ((noninteractive (sys:getenv "ACL_NONINTERACTIVE")))
    (when (or (null noninteractive)
	      (string= "" noninteractive))
      (excl::internal-message-box msg "CG/JS Installation" :type :ok))))
